@@ -248,7 +248,7 @@ def decorate_template(mlist, template, extradict=None):
         substitutions.update(extradict)
     text = expand(template, mlist, substitutions)
     # Turn any \r\n line endings into just \n
-    return re.sub(r' *\r?\n', r'\n', text)
+    return re.sub(r'\r\n', r'\n', text)
 
 
 @public
@@ -260,5 +260,5 @@ class Decorate:
     description = _('Decorate a message with headers and footers.')
 
     def process(self, mlist, msg, msgdata):
-        "See `IHandler`."""
+        """See `IHandler`."""
         process(mlist, msg, msgdata)
