@@ -121,10 +121,14 @@ def deliver(mlist, msg, msgdata):
         # Log the successful post, but if it was not destined to the mailing
         # list (e.g. to the owner or admin), print the actual recipients
         # instead of just the number.
-        if not msgdata.get('tolist', False):
+        if not msgdata.get('to_list', False):
+            # XXX This is meaningless as the config.logging.smtp.success
+            # template doesn't contain a recip substitution, but do it anyway
+            # in case the template is changed.
             recips = msg.get_all('to', [])
             recips.extend(msg.get_all('cc', []))
-            substitutions['recips'] = COMMA.join(recips)
+            # recips can contain a Header() instance.  Stringify it.
+            substitutions['recip'] = COMMA.join(map(str, recips))
         template = config.logging.smtp.success
         if template.lower() != 'no':
             log.info('%s', expand(template, mlist, substitutions))
@@ -142,8 +146,9 @@ def deliver(mlist, msg, msgdata):
         #   so the logic below works.
         #
         if code >= 500 and code != 552:
-            # A permanent failure
-            permanent_failures.append(recipient)
+            # A permanent failure.  Keep the code and message for a fake DSN.
+            permanent_failures.append(
+                (recipient, code, smtp_message))    # pragma: nocover
         else:
             # Deal with persistent transient failures by queuing them up for
             # future delivery.  TBD: this could generate lots of log entries!
